==> wicket-extensions-1.4.0-sources.jar: org/apache/wicket/extensions/ajax/markup/html/autocomplete/StringAutoCompleteRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.extensions.ajax.markup.html.autocomplete;

/**
 * An renderer that assumes that assist objects are {@link String}s. Great for quickly generating a
 * list of assists.
 * 
 * @since 1.2
 * 
 * @author Igor Vaynberg (ivaynberg)
 * 
 */
public final class StringAutoCompleteRenderer extends AbstractAutoCompleteTextRenderer<Object>
{
	private static final long serialVersionUID = 1L;

	/**
	 * A singleton instance
	 */
	@SuppressWarnings("unchecked")
	public static final IAutoCompleteRenderer INSTANCE = new StringAutoCompleteRenderer();

	/**
	 * @param <T>
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public static final <T> IAutoCompleteRenderer<T> instance()
	{
		return INSTANCE;
	}

	/**
	 * @see AbstractAutoCompleteTextRenderer#getTextValue(Object)
	 */
	@Override
	protected String getTextValue(Object object)
	{
		return object.toString();
	}

}

==> wicket-extensions-1.4.22-sources.jar: org/apache/wicket/extensions/ajax/markup/html/autocomplete/StringAutoCompleteRenderer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.extensions.ajax.markup.html.autocomplete;

/**
 * An renderer that calls object.toString() to get the text value. Great for quickly generating a
 * list of assists.
 * 
 * @since 1.2
 * 
 * @author Igor Vaynberg (ivaynberg)
 */
public final class StringAutoCompleteRenderer extends AbstractAutoCompleteTextRenderer<Object>
{
	private static final long serialVersionUID = 1L;

	/**
	 * A singleton instance
	 */
	@SuppressWarnings("unchecked")
	public static final IAutoCompleteRenderer INSTANCE = new StringAutoCompleteRenderer();

	/**
	 * @param <T>
	 * @return A static instance of the class
	 */
	@SuppressWarnings("unchecked")
	public static final <T> IAutoCompleteRenderer<T> instance()
	{
		return INSTANCE;
	}

	/**
	 * @see AbstractAutoCompleteTextRenderer#getTextValue(Object)
	 */
	@Override
	protected String getTextValue(Object object)
	{
		return object.toString();
	}

}
